
# finance
finance_cash_flow_url = "https://stock.xueqiu.com/v5/stock/finance/cn/cash_flow.json?symbol="
finance_indicator_url = "https://stock.xueqiu.com/v5/stock/finance/cn/indicator.json?symbol="
finance_balance_url = "https://stock.xueqiu.com/v5/stock/finance/cn/balance.json?symbol="
finance_income_url = "https://stock.xueqiu.com/v5/stock/finance/cn/income.json?symbol="
finance_business_url = "https://stock.xueqiu.com/v5/stock/finance/cn/business.json?symbol="

# report
report_latest_url = "https://stock.xueqiu.com/stock/report/latest.json?symbol="
report_earningforecast_url = "https://stock.xueqiu.com/stock/report/earningforecast.json?symbol="

# capital
capital_margin_url = "https://stock.xueqiu.com/v5/stock/capital/margin.json?symbol="
capital_blocktrans_url = "https://stock.xueqiu.com/v5/stock/capital/blocktrans.json?symbol="
capital_assort_url = "https://stock.xueqiu.com/v5/stock/capital/assort.json?symbol="
capital_history_url = "https://stock.xueqiu.com/v5/stock/capital/history.json?symbol="
capital_flow_url = "https://stock.xueqiu.com/v5/stock/capital/flow.json?symbol="

# f10
f10_skholderchg = "https://stock.xueqiu.com/v5/stock/f10/cn/skholderchg.json?symbol="
f10_skholder = "https://stock.xueqiu.com/v5/stock/f10/cn/skholder.json?symbol="
f10_industry = "https://stock.xueqiu.com/v5/stock/f10/cn/industry.json?symbol="
f10_holders = "https://stock.xueqiu.com/v5/stock/f10/cn/holders.json?&symbol="
f10_bonus = "https://stock.xueqiu.com/v5/stock/f10/cn/bonus.json?&symbol="
f10_org_holding_change = "https://stock.xueqiu.com/v5/stock/f10/cn/org_holding/change.json?symbol="
f10_industry_compare = "https://stock.xueqiu.com/v5/stock/f10/cn/industry/compare.json?type=single&symbol="
f10_business_analysis = "https://stock.xueqiu.com/v5/stock/f10/cn/business_analysis.json?symbol="
f10_shareschg = "https://stock.xueqiu.com/v5/stock/f10/cn/business_analysis.json?symbol="
f10_top_holders = "https://stock.xueqiu.com/v5/stock/f10/cn/top_holders.json?&symbol="

# real time
realtime_quote = "https://stock.xueqiu.com/v5/stock/realtime/quotec.json?symbol="
realtime_pankou = "https://xueqiu.com/stock/pankou.json?symbol="
